==> zio-aws-ec2_2.13-5.17.127.2-sources.jar: zio/aws/ec2/model/UnsuccessfulInstanceCreditSpecificationItemError.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UnsuccessfulInstanceCreditSpecificationItemError(
    code: Option[
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ] = None,
    message: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError = {
    import UnsuccessfulInstanceCreditSpecificationItemError.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError.ReadOnly =
    zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
      .wrap(buildAwsValue())
}
object UnsuccessfulInstanceCreditSpecificationItemError {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError =
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Option[
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ]
    def message: Option[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
  ) extends zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError.ReadOnly {
    override val code: Option[
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ] = scala
      .Option(impl.code())
      .map(value =>
        zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
          .wrap(value)
      )
    override val message: Option[String] =
      scala.Option(impl.message()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
  ): zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.20.17.1-sources.jar: zio/aws/ec2/model/UnsuccessfulInstanceCreditSpecificationItemError.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UnsuccessfulInstanceCreditSpecificationItemError(
    code: Optional[
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ] = Optional.Absent,
    message: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError = {
    import UnsuccessfulInstanceCreditSpecificationItemError.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError.ReadOnly =
    zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
      .wrap(buildAwsValue())
}
object UnsuccessfulInstanceCreditSpecificationItemError {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError =
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Optional[
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ]
    def message: Optional[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
  ) extends zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError.ReadOnly {
    override val code: Optional[
      zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.code())
      .map(value =>
        zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationErrorCode
          .wrap(value)
      )
    override val message: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError
  ): zio.aws.ec2.model.UnsuccessfulInstanceCreditSpecificationItemError.ReadOnly =
    new Wrapper(impl)
}
